==> gcc-java-4.2.2.tar.bz2: gcc-4.2.2/libjava/classpath/gnu/javax/crypto/jce/prng/CSPRNGSpi.java <==
/* CSPRNGSpi.java -- 
   Copyright (C) 2004, 2006  Free Software Foundation, Inc.

This file is a part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
USA

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.  */


package gnu.javax.crypto.jce.prng;

import gnu.java.security.prng.IRandom;
import gnu.java.security.prng.LimitReachedException;
import gnu.javax.crypto.prng.CSPRNG;

import java.net.MalformedURLException;
import java.security.SecureRandomSpi;

/**
 * The implementation of the continuously-seeded SecureRandom <i>Service
 * Provider Interface</i> (<b>SPI</b>) adapter.
 */
public class CSPRNGSpi
    extends SecureRandomSpi
{
  private final IRandom adaptee;

  public CSPRNGSpi() throws ClassNotFoundException, MalformedURLException,
      NumberFormatException
  {
    super();

    adaptee = CSPRNG.getSystemInstance();
  }

  protected byte[] engineGenerateSeed(final int count)
  {
    if (count < 0)
      throw new IllegalArgumentException("count must be nonnegative");
    byte[] buf = new byte[count];
    if (count == 0)
      return buf;
    engineNextBytes(buf);
    return buf;
  }

  protected void engineNextBytes(final byte[] buffer)
  {
    if (buffer == null)
      throw new NullPointerException();
    try
      {
        adaptee.nextBytes(buffer, 0, buffer.length);
      }
    catch (LimitReachedException lre)
      {
        throw new RuntimeException("random-number generator has been exhausted");
      }
  }

  protected void engineSetSeed(final byte[] seed)
  {
    if (seed == null)
      throw new NullPointerException();
    adaptee.addRandomBytes(seed, 0, seed.length);
  }
}

==> gcc-java-4.5.2.tar.bz2: gcc-4.5.2/libjava/classpath/gnu/javax/crypto/jce/prng/CSPRNGSpi.java <==
/* CSPRNGSpi.java -- 
   Copyright (C) 2004, 2006  Free Software Foundation, Inc.

This file is a part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at
your option) any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
USA

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.  */


package gnu.javax.crypto.jce.prng;

import gnu.java.security.prng.IRandom;
import gnu.java.security.prng.LimitReachedException;
import gnu.java.security.jce.prng.SecureRandomAdapter;
import gnu.javax.crypto.prng.CSPRNG;

import java.net.MalformedURLException;
import java.security.SecureRandomSpi;

/**
 * The implementation of the continuously-seeded SecureRandom <i>Service
 * Provider Interface</i> (<b>SPI</b>) adapter.
 */
public class CSPRNGSpi
    extends SecureRandomSpi
{
  private final IRandom adaptee;
  private boolean virgin = true;

  public CSPRNGSpi() throws ClassNotFoundException, MalformedURLException,
      NumberFormatException
  {
    super();

    adaptee = CSPRNG.getSystemInstance();
  }

  protected byte[] engineGenerateSeed(final int numBytes)
  {
    return SecureRandomAdapter.getSeed(numBytes);
  }

  protected void engineNextBytes(final byte[] buffer)
  {
    if (buffer == null)
      throw new NullPointerException();
    if (virgin)
      {
        engineSetSeed(engineGenerateSeed(32));
      }
    try
      {
        adaptee.nextBytes(buffer, 0, buffer.length);
      }
    catch (LimitReachedException lre)
      {
        throw new RuntimeException("random-number generator has been exhausted");
      }
  }

  protected void engineSetSeed(final byte[] seed)
  {
    if (seed == null)
      throw new NullPointerException();
    adaptee.addRandomBytes(seed, 0, seed.length);
    virgin = false;
  }
}
